==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/SliceEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SliceEventArgsDescription } from "./SliceEventArgsDescription";
/**
 * @hidden
 */
var SliceEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SliceEventArgsDescriptionMetadata, _super);
    function SliceEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SliceEventArgsDescriptionMetadata.b = function (a) {
        if (SliceEventArgsDescriptionMetadata.a == null) {
            SliceEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SliceEventArgsDescriptionMetadata.c(SliceEventArgsDescriptionMetadata.a);
        }
        if (a.j(SliceEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(SliceEventArgsDescriptionMetadata.a);
    };
    SliceEventArgsDescriptionMetadata.c = function (a) {
        a.item("IsSelected", "Boolean");
        a.item("IsExploded", "Boolean");
        a.item("OriginalEventRef", "(w:OriginalEvent,wf:OriginalEvent)DataRef");
    };
    SliceEventArgsDescriptionMetadata.d = function (a) {
        SliceEventArgsDescriptionMetadata.b(a);
        a.aa("SliceEventArgs", function () { return new SliceEventArgsDescription(); });
        a.z("SliceEventArgs", SliceEventArgsDescriptionMetadata.a);
    };
    SliceEventArgsDescriptionMetadata.$t = markType(SliceEventArgsDescriptionMetadata, 'SliceEventArgsDescriptionMetadata');
    SliceEventArgsDescriptionMetadata.a = null;
    return SliceEventArgsDescriptionMetadata;
}(Base));
export { SliceEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/SliceEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SliceEventArgsDescription } from "./SliceEventArgsDescription";
/**
 * @hidden
 */
var SliceEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SliceEventArgsDescriptionMetadata, _super);
    function SliceEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SliceEventArgsDescriptionMetadata.b = function (a) {
        if (SliceEventArgsDescriptionMetadata.a == null) {
            SliceEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SliceEventArgsDescriptionMetadata.c(SliceEventArgsDescriptionMetadata.a);
        }
        if (a.k(SliceEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(SliceEventArgsDescriptionMetadata.a);
    };
    SliceEventArgsDescriptionMetadata.c = function (a) {
        a.item("IsSelected", "Boolean");
        a.item("IsExploded", "Boolean");
        a.item("OriginalEventRef", "(w:OriginalEvent,wf:OriginalEvent)DataRef");
    };
    SliceEventArgsDescriptionMetadata.d = function (a) {
        SliceEventArgsDescriptionMetadata.b(a);
        a.ac("SliceEventArgs", function () { return new SliceEventArgsDescription(); });
        a.ab("SliceEventArgs", SliceEventArgsDescriptionMetadata.a);
    };
    SliceEventArgsDescriptionMetadata.$t = markType(SliceEventArgsDescriptionMetadata, 'SliceEventArgsDescriptionMetadata');
    SliceEventArgsDescriptionMetadata.a = null;
    return SliceEventArgsDescriptionMetadata;
}(Base));
export { SliceEventArgsDescriptionMetadata };
